# Contributing

👋 Welcome to InftyAI community !

- [Before you get started](#before-you-get-started)
  - [Code of Conduct](#code-of-conduct)
- [Getting started](#getting-started)
  - [PullRequests](#pull-requests)
  - [Code Review](#code-review)

## Before you get started

### Code of Conduct

Please make sure to read and observe our [Code of Conduct](/CODE_OF_CONDUCT.md) first.

## Getting started

🚀 **All kinds of contributions are welcomed !**

- Fix documents & Typos
- Report & fix bugs
- New features
- Issues & discussions
- ...

### Pull Requests

Pull requests are often called simply "PR".
Please follows the standard [github pull request](https://help.github.com/articles/about-pull-requests/) process.
To submit a proposed change, please develop the code and add new test cases.

### Code Review

To make it easier for your PR to receive reviews, consider the reviewers will need you to:

- Follow [good coding guidelines](https://github.com/golang/go/wiki/CodeReviewComments).
- Write [good commit messages](https://chris.beams.io/posts/git-commit/).
- Break large changes into a logical series of smaller patches which individually make easily understandable changes, and in aggregate solve a broader issue.
